class pckg:
    def __init__(self):
        print("Hello Welcome to utsav Library.")
        
    def sum(self,num1,num2):
        return num1 + num2

    def sub(self,num1,num2):
        return num1 - num2

    def mul(self,num1,num2):
        return num1 * num2
    
    def div(self,num1,num2):
        return num1 / num2
